within TAeZoSysPro.Aeraulic.BasesClasses;

model MolecularDiffusion
  // to finish
  package Medium = Media.SimpleDryAirH2;
  parameter Modelica.SIunits.Thickness e = 1;
  parameter Modelica.SIunits.CrossSection A = 0;
  Real gradX[Medium.nX](each quantity="spatial gradient",each unit="m-1") "gradient of mass fraction" ;
  Real gradY[Medium.nX](each quantity="spatial gradient",each unit="m-1") "gradient of mole fraction" ;
  Modelica.SIunits.DiffusionCoefficient[Medium.nX,Medium.nX] D;
  Modelica.SIunits.MassFlowRate[Medium.nX] m_flow;
  Modelica.SIunits.Density d;
  Modelica.SIunits.MolarMass MMmean ; 
  TAeZoSysPro.Aeraulic.Interfaces.FlowPort_a flowPort_a(replaceable package Medium = Medium) annotation(
    Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-102, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  TAeZoSysPro.Aeraulic.Interfaces.FlowPort_b flowPort_b(replaceable package Medium = Medium) annotation(
    Placement(visible = true, transformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));

protected
  Real J[Medium.nX](each quantity="mass flux rate",each unit="kg.m-2.s-1") "gradient of mass fraction" ;
  Modelica.SIunits.MassFraction[Medium.nX] Xa, Xb ;
  Modelica.SIunits.MoleFraction[Medium.nX] Ya, Yb ; 
  
equation
  Ya = flowPort_a.pi / sum(flowPort_a.pi) ;
  Yb = flowPort_b.pi / sum(flowPort_b.pi) ;
  Xa = flowPort_a.di / sum(flowPort_a.di) ;
  Xb = flowPort_b.di / sum(flowPort_b.di) ;
  D = Medium.MolecularDiffusionCoeff(T = (flowPort_a.T + flowPort_b.T) / 2 , p = (sum(flowPort_a.pi) + sum(flowPort_b.pi)) / 2) ;
  //MMmean = 1 / sum( (Xa[i] + Xb[i])/2 / Medium.MMX[i] for i in 1:Medium.nX) ;
  MMmean = sum( (Ya[i] + Yb[i])/2 * Medium.MMX[i] for i in 1:Medium.nX ) ;
  d = 1/2 * (sum(flowPort_a.di) + sum(flowPort_b.di)) ;
  for i in 1:Medium.nX loop
    gradX[i] = 1 / e * ( Xb[i] - Xa[i] ) ;
    gradY[i] = 1 / e * ( Yb[i] - Ya[i] ) ;
    // from stefan Maxell equation : not working currently
      //J[i] = - d / MMmean^2 * sum(Medium.MMX[i] * Medium.MMX[j] * D[i,j] for j in 1:Medium.nX) * gradY[i] ;    
    m_flow[i] = J[i] * A ;
  end for ;
  // from fick equation
    J[1] = - d * D[1,2] * gradX[1] ;
    J[2] = - J[1] ;
  flowPort_a.m_flow = m_flow ;
  flowPort_a.H_flow = sum(if m_flow[i] >= 0.0 then flowPort_a.hi[i] * m_flow[i] else flowPort_b.hi[i] * m_flow[i] for i in 1:Medium.nX) ;
  flowPort_a.m_flow = - flowPort_b.m_flow ;
  flowPort_a.H_flow + flowPort_b.H_flow = 0.0 ;
  
  annotation(
    Diagram(graphics = {Ellipse(origin = {-52, 80}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 68}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 56}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 20}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 44}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 32}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -40}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -28}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -52}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -16}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -4}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 8}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -76}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -64}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, 62}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, 74}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, 50}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 64}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, 38}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, 26}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, 14}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, 2}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, -10}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, -22}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, -34}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, -46}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, -58}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, -70}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 40}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 16}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -8}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -32}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -56}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -78}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 86}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, 86}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, -80}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Rectangle(fillColor = {0, 170, 255}, extent = {{-56, 88}, {62, -84}}), Ellipse(origin = {54, 80}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 8}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -4}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -16}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 32}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 44}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 20}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 56}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 68}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -28}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -40}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -52}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -64}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -76}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, 86}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, 62}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, 38}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, 14}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, -10}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, -34}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, -58}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, -80}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, 74}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, 50}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, 26}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, 2}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, -22}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, -46}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, -70}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 86}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 64}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 40}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 16}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -8}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -32}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -56}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -78}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, 64}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, 42}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, 18}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, -6}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, -30}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, -54}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 76}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 54}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 30}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 6}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -18}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -42}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -66}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, -76}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {46, 74}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {46, 26}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {46, -22}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {46, -70}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 76}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 54}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 30}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 6}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -18}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -42}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -66}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, 64}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, 40}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, 16}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, -8}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, -32}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, -56}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, -80}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, 86}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-44, 74}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-44, 26}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-44, -22}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-44, -70}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Line(origin = {0, 2}, points = {{0, 86}, {0, -86}}, pattern = LinePattern.Dot)}, coordinateSystem(initialScale = 0.1)),
    Icon(graphics = {Ellipse(origin = {-52, 80}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 68}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 56}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 20}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 44}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 32}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -40}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -28}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -52}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -16}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -4}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, 8}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -76}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-52, -64}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, 62}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, 74}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, 50}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 64}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, 38}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, 26}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, 14}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, 2}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, -10}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, -22}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, -34}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, -46}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, -58}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-30, -70}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 40}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 16}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -8}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -32}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -56}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -78}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 86}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, 86}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-40, -80}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Rectangle(fillColor = {0, 170, 255}, extent = {{-56, 88}, {62, -84}}), Ellipse(origin = {54, 80}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 8}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -4}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -16}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 32}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 44}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 20}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 56}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, 68}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -28}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -40}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -52}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -64}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {54, -76}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, 86}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, 62}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, 38}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, 14}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, -10}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, -34}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, -58}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {42, -80}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, 74}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, 50}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, 26}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, 2}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, -22}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, -46}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {30, -70}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 86}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 64}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 40}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 16}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -8}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -32}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -56}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -78}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, 64}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, 42}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, 18}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, -6}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, -30}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, -54}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 76}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 54}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 30}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, 6}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -18}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -42}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {10, -66}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {24, -76}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {46, 74}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {46, 26}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {46, -22}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {46, -70}, fillColor = {0, 85, 255}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 76}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 54}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 30}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, 6}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -18}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -42}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-12, -66}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, 64}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, 40}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, 16}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, -8}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, -32}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, -56}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, -80}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-24, 86}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-44, 74}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-44, 26}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-44, -22}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Ellipse(origin = {-44, -70}, fillColor = {255, 0, 0}, fillPattern = FillPattern.Solid, extent = {{-2, 2}, {4, -4}}, endAngle = 360), Line(origin = {0, 2}, points = {{0, 86}, {0, -86}}, pattern = LinePattern.Dot)}, coordinateSystem(initialScale = 0.1)));
end MolecularDiffusion;
